A Bird's Eye View
=================

We now take a whirlwind tour of some of the number theoretical
functionality of Sage.  There is much that we won't cover here, but
this should help give you a flavor for some of the number theoretic
capabilities of Sage, much of which is unique to Sage.

.. toctree::
   :maxdepth: 2

   integer_factorization
   elliptic_curves
   birds_other
